//  Copyright (c) 2007-2012 Hartmut Kaiser
//
//  SPDX-License-Identifier: BSL-1.0
//  Distributed under the Boost Software License, Version 1.0. (See accompanying
//  file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)

#include <hpx/config.hpp>
#if !defined(HPX_COMPUTE_DEVICE_CODE)
#include <hpx/hpx.hpp>
#include <hpx/runtime_configuration/component_factory_base.hpp>

#include "throttle.hpp"

///////////////////////////////////////////////////////////////////////////////
// Add factory registration functionality
HPX_REGISTER_COMPONENT_MODULE()    // create entry point for component factory

///////////////////////////////////////////////////////////////////////////////
typedef throttle::throttle throttle_client_type;
HPX_DEFINE_GET_COMPONENT_TYPE(throttle_client_type)

#endif
